Crate sbpf_assembler

Crate sbpf_assembler 

Re-exports

pub use self::ast::OptimizationConfig;
pub use self::astnode::ASTNode;
pub use self::debug::DebugData;
pub use self::errors::CompileError;
pub use self::parser::ProgramLayout;
pub use self::parser::Token;
pub use self::parser::parse;
pub use self::parser::parse_with_optimization;
pub use self::preprocessor::FileResolver;
pub use self::preprocessor::FsFileResolver;
pub use self::preprocessor::MockFileResolver;
pub use self::preprocessor::PreprocessResult;
pub use self::preprocessor::preprocess;
pub use self::preprocessor::source_map::FileRegistry;
pub use self::preprocessor::source_map::SourceMap;
pub use self::preprocessor::source_map::SourceOrigin;
pub use self::program::Program;

Modules

ast
astnode
debug
dynsym
errors
header
macros
optimizer
parser
preprocessor
program
section

Macros

bug
define_compile_errors

Structs

AssembleErrors
Returned when assembly with preprocessing fails. Contains the errors and the file registry so callers can render diagnostics against the original source files.
Assembler
Assembler for SBPF assembly code
AssemblerError
An error enriched with source location information from preprocessing. Wraps a CompileError with the resolved original source location.
AssemblerOption
Options for the assembler
DebugMode
Debug mode configuration for the assembler

Enums

SbpfArch
sBPF target architecture