Module source_map

Module source_map 

Structs

FileId
Opaque handle into the file registry
FileRegistry
Registry of all source files encountered during preprocessing
MacroExpansionInfo
Information about a macro expansion in the call stack
SourceMap
Maps byte offsets in expanded text back to original source locations.
SourceOrigin
Where a line of expanded output originally came from