pub struct SourceOrigin {
pub file_id: FileId,
pub line: u32,
pub macro_expansion: Option<Box<MacroExpansionInfo>>,
}Expand description
Where a line of expanded output originally came from
Fields
file_id: FileIdline: u321-based line number in the original file
macro_expansion: Option<Box<MacroExpansionInfo>>If this line was produced by a macro expansion, the chain of expansions
Implementations
Sourceimpl SourceOrigin
impl SourceOrigin