assign_offsets

Function assign_offsets 

pub fn assign_offsets(ast: &mut AST)
Recomputes byte offsets for all labels and instructions in the AST from scratch, in node order. Called after any pass that alters the node list so there is a single authoritative place that assigns offsets.